@@ -177,7 +177,8 @@ testWildcardAltNames2() {
         --cn somehost.spapps.ethz.ch \
         --cn otherhost.sPaPPs.ethz.ch \
         --cn spapps.ethz.ch \
-        --rootcert cabundle.crt --altnames
+        --rootcert cabundle.crt --altnames \
+       
     EXIT_CODE=$?
     assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
 }
@@ -206,7 +207,7 @@ testXMPPHost() {
     # $TRAVIS is set an environment variable
     # shellcheck disable=SC2154
     if [ -z "${TRAVIS+x}" ] ; then
-        out=$(${SCRIPT} -H prosody.xmpp.is --port 5222 --protocol xmpp --xmpphost xmpp.is)
+        out=$(${SCRIPT} -H prosody.xmpp.is --port 5222 --protocol xmpp --xmpphost xmpp.is )
         EXIT_CODE=$?
         if echo "${out}" | grep -q "s_client' does not support '-xmpphost'" ; then
             assertEquals "wrong exit code" "${NAGIOS_UNKNOWN}" "${EXIT_CODE}"
@@ -226,7 +227,7 @@ testTimeOut() {
 
 testIMAP() {
     if [ -z "${TRAVIS+x}" ] ; then
-	# minimal critical and warning as they renew pretty late
+        # minimal critical and warning as they renew pretty late
         ${SCRIPT} --rootcert cabundle.crt -H imap.gmx.com --port 143 --timeout 30 --protocol imap --critical 1 --warning 2
         EXIT_CODE=$?
         assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
@@ -330,6 +331,12 @@ testBadSSLRevoked() {
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
+testBadSSLRevokedCRL() {
+    ${SCRIPT} -H revoked.badssl.com --host-cn --crl --rootcert-file cabundle.crt --ignore-ocsp
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+}
+
 testGRCRevoked() {
     ${SCRIPT} -H revoked.grc.com --host-cn
     EXIT_CODE=$?
@@ -342,6 +349,54 @@ testBadSSLIncompleteChain() {
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
+testBadSSLDH480(){
+    ${SCRIPT} -H dh480.badssl.com --host-cn
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+}
+
+testBadSSLDH512(){
+    ${SCRIPT} -H dh512.badssl.com --host-cn
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+}
+
+testBadSSLRC4MD5(){
+    if [ -z "${TRAVIS+x}" ] ; then
+        ${SCRIPT} -H rc4-md5.badssl.com --host-cn
+        EXIT_CODE=$?
+        assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+    else
+        echo "Skipping RC4 MD5 with badssl.com on Travis CI (OpenSSL too old)"
+    fi
+}
+
+testBadSSLRC4(){
+    if [ -z "${TRAVIS+x}" ] ; then
+        ${SCRIPT} -H rc4.badssl.com --host-cn
+        EXIT_CODE=$?
+        assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+    else
+        echo "Skipping RC4 with badssl.com on Travis CI (OpenSSL too old)"
+    fi
+}
+
+testBadSSL3DES(){
+    if [ -z "${TRAVIS+x}" ] ; then
+        ${SCRIPT} -H 3des.badssl.com --host-cn
+        EXIT_CODE=$?
+        assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+    else
+        echo "Skipping 3DES with badssl.com on Travis CI (OpenSSL too old)"
+    fi
+}
+
+testBadSSLNULL(){
+    ${SCRIPT} -H null.badssl.com --host-cn
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+}
+
 testBadSSLSHA256() {
     if [ -z "${TRAVIS+x}" ] ; then
         ${SCRIPT} -H sha256.badssl.com --host-cn
@@ -571,6 +626,25 @@ testNotLongerValidThan() {
     assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
 }
 
+testCertificsteWithoutCN() {
+    ${SCRIPT} -H localhost -n www.uue.org -f ./cert_with_subject_without_cn.crt --force-perl-date --ignore-sig-alg --ignore-sct
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+}
+
+testCertificsteWithEmptySubject() {
+    ${SCRIPT} -H localhost -n www.uue.org -f ./cert_with_empty_subject.crt --force-perl-date --ignore-sig-alg --ignore-sct
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_OK}" "${EXIT_CODE}"
+}
+
+testSCT() {
+    ${SCRIPT} -H no-sct.badssl.com
+    EXIT_CODE=$?
+    assertEquals "wrong exit code" "${NAGIOS_CRITICAL}" "${EXIT_CODE}"
+}
+    
+
 # SSL Labs (last one as it usually takes a lot of time
 
 testETHZWithSSLLabs() {
